@@ -115,7 +115,7 @@ class VQA(AbstractVQA):
             for split in self.filename_questions.keys()
         }  # vqa2/train/
 
-        self.dir_splits["test-dev"] = "test"  # same directory
+        self.dir_splits["test-dev"] = self.dir_splits["test"]  # same directory
 
         for s in self.dir_splits:
             os.makedirs(self.dir_splits[s], exist_ok=True)
@@ -170,6 +170,10 @@ class VQA(AbstractVQA):
             # aid_to_ans
             self.ans_to_aid = {ans: i for i, ans in enumerate(self.answers)}
 
+    @classmethod
+    def download_and_process(cls, dir_data):
+        cls(dir_data=dir_data, split="train", load="False")
+
     def _load_questions(self, split):
         with open(self.path_questions[split]) as f:
             return json.load(f)["questions"]
@@ -308,19 +312,24 @@ class VQA(AbstractVQA):
 
     def __getitem__(self, index):
         """
-        Returns a dictionnary with the following keys : {
-            'image_id', 
-            'question_id',
-            'question', 
-            'answer_type',
-            'multiple_choice_answer',
-            'answers',
-            'image_id',
-            'question_type',
-            'question_id',
-            'scores',
-            'label'   # ground truth label to be used for the loss
-        }
+        Returns a dictionnary with the following keys 
+
+        .. code-block::
+
+            {
+                'image_id', 
+                'question_id',
+                'question', 
+                'answer_type',
+                'multiple_choice_answer',
+                'answers',
+                'image_id',
+                'question_type',
+                'question_id',
+                'scores',
+                'label'   # ground truth label to be used for the loss
+            }
+
         Aditionnaly, if visual features are used, keys from the features will be added.
         """
         item = {"index": index}
